summaryrefslogtreecommitdiff
path: root/linux-core/drm_crtc.h
diff options
context:
space:
mode:
Diffstat (limited to 'linux-core/drm_crtc.h')
-rw-r--r--linux-core/drm_crtc.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/linux-core/drm_crtc.h b/linux-core/drm_crtc.h
index 36d5f316..19d7cf51 100644
--- a/linux-core/drm_crtc.h
+++ b/linux-core/drm_crtc.h
@@ -377,7 +377,7 @@ struct drm_output {
};
/**
* struct drm_crtc_config_funcs - configure CRTCs for a given screen layout
* @resize: adjust CRTCs as necessary for the proposed layout
*
* Currently only a resize hook is available. DRM will call back into the
@@ -385,15 +385,15 @@ struct drm_output {
* the proposed size, it can return false. Otherwise it should adjust
* the CRTC<->output mappings as needed and update its view of the screen.
*/
-struct drm_crtc_config_funcs {
+struct drm_mode_config_funcs {
bool (*resize)(struct drm_device *dev, int width, int height);
};
/**
* drm_crtc_config - CRTC configuration control structure
*
*/
-struct drm_crtc_config {
+struct drm_mode_config {
spinlock_t config_lock;
struct idr crtc_idr; /* use this idr for all IDs, fb, crtc, output, modes - just makes life easier */
/* this is limited to one for now */
@@ -410,7 +410,7 @@ struct drm_crtc_config {
int max_width, max_height;
/* DamagePtr rotationDamage? */
/* DGA stuff? */
- struct drm_crtc_config_funcs *funcs;
+ struct drm_mode_config_funcs *funcs;
};
struct drm_output *drm_output_create(struct drm_device *dev,
@@ -427,8 +427,8 @@ extern struct drm_display_mode *drm_mode_duplicate(struct drm_device *dev,
struct drm_display_mode *mode);
extern void drm_mode_debug_printmodeline(struct drm_device *dev,
struct drm_display_mode *mode);
-extern void drm_crtc_config_init(struct drm_device *dev);
-extern void drm_crtc_config_cleanup(struct drm_device *dev);
+extern void drm_mode_config_init(struct drm_device *dev);
+extern void drm_mode_config_cleanup(struct drm_device *dev);
extern void drm_disable_unused_functions(struct drm_device *dev);
extern struct drm_display_mode *drm_crtc_mode_create(struct drm_device *dev);
@@ -377,7 +377,7 @@ struct drm_output {
};
/**
- * struct drm_crtc_config_funcs - configure CRTCs for a given screen layout
+ * struct drm_mode_config_funcs - configure CRTCs for a given screen layout
* @resize: adjust CRTCs as necessary for the proposed layout
*
@@ -385,15 +385,15 @@ struct drm_output {
};
/**
- * drm_crtc_config - CRTC configuration control structure
+ * drm_mode_config - Mode configuration control structure
*
*/